grim/guifications3

updated for the GfFeedPool -> GfFeedManager change
org.guifications.gf3
2009-09-19, Gary Kramlich
1eb2d2977119
Parents 5594ef12624f
Children 986f87ee20d0
updated for the GfFeedPool -> GfFeedManager change

refs #43
--- a/guifications-daemon-web/src/guifications-daemon-web-handler-feeds.c Sat Sep 19 00:19:39 2009 -0500
+++ b/guifications-daemon-web/src/guifications-daemon-web-handler-feeds.c Sat Sep 19 00:22:06 2009 -0500
@@ -25,7 +25,7 @@
gpointer data)
{
GfConnection *connection = GF_CONNECTION(data);
- GfFeedPool *feed_pool = NULL;
+ GfFeedManager *feed_manager = NULL;
GPlateTemplate *tplate = NULL;
GPlateVariable *dict = NULL;
GError *error = NULL;
@@ -36,13 +36,13 @@
dict = gplate_dictionary_variable_new("feeds");
gplate_collection_add_variable(GPLATE_COLLECTION(tplate), dict);
- /* grab the feed pool and add them to the dictionary */
- feed_pool = gf_connection_get_feed_pool(connection);
- if(GF_IS_FEED_POOL(feed_pool)) {
+ /* grab the feed manager and add them to the dictionary */
+ feed_manager = gf_connection_get_feed_manager(connection);
+ if(GF_IS_FEED_MANAGER(feed_manager)) {
GfFeed **feeds = NULL;
gint i = 0;
- feeds = gf_feed_pool_list_feeds(feed_pool, NULL);
+ feeds = gf_feed_manager_list_feeds(feed_manager, NULL);
for(i = 0; GF_IS_FEED(feeds[i]); i++) {
GPlateVariable *var = NULL;